MODULE sbc_ice
   !!======================================================================
   !!                 ***  MODULE  sbc_ice  ***
   !!        parameter and  variables defined in memory in forced mode
   !!======================================================================
   !! History :  9.0  !  06-08  (G. Modec)  Surface module
   !!----------------------------------------------------------------------
#if defined key_ice_lim
   !!----------------------------------------------------------------------
   !!   'key_ice_lim' :                                   Lim sea-ice model
   !!----------------------------------------------------------------------
   USE par_oce          ! ocean parameters

   IMPLICIT NONE
   PRIVATE

   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   utaui_ice   !: u-stress over ice (I-point)   [N/m2]
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   vtaui_ice   !: v-stress over ice (I-point)   [N/m2]
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   qns_ice     !: non solar heat flux over ice  [W/m2]
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   qsr_ice     !: solar heat flux over ice      [W/m2]
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   dqns_ice    !: non solar heat flux sensibility over ice (LW+SEN+LA) [W/m2/K]
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   tn_ice      !: ice surface temperature       [K]
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   tprecip     !: total precipitation           [Kg/m2/s]
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   sprecip     !: solid precipitation           [Kg/m2/s]
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   fr1_i0      !: 1st fraction of sol. rad.  which penetrate inside the ice cover
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   fr2_i0      !: 2nd fraction of sol. rad.  which penetrate inside the ice cover

   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   &
#if ! defined key_coupled
      qla_ice  ,      &  !: latent flux over ice  
      dqla_ice           !: latent sensibility over ice
#else
      rrunoff  ,      &  !: runoff
      calving  ,      &  !: calving
      alb_ice            !: albedo of ice      
#endif

#else
   !!----------------------------------------------------------------------
   !!   Empty module                                   NO LIM sea-ice model
   !!----------------------------------------------------------------------
#endif

   !!----------------------------------------------------------------------
   !!  OPA 9.0 , LOCEAN-IPSL (2005)
   !! $Header: $
   !! Software governed by the CeCILL licence (modipsl/doc/NEMO_CeCILL.txt)
   !!----------------------------------------------------------------------
END MODULE sbc_ice
